.. _api_reference:

=============
API reference
=============


System
======

.. autosummary::
   :maxdepth:4
   :recursive:
   :toctree: _generated
   :caption: System
   :template: autosummary/module_toctree.rst

   andes.system
   andes.variables


Routines
========

.. autosummary::
   :maxdepth:4
   :recursive:
   :toctree: _generated
   :caption: Routines
   :template: autosummary/module_toctree.rst

   andes.routines


Plot
====
.. autosummary::
   :maxdepth:4
   :toctree: _generated
   :recursive:
   :caption: Plot

   andes.plot

I/O
===

.. autosummary::
   :maxdepth:4
   :toctree: _generated
   :recursive:
   :caption: I/O
   :template: autosummary/module_toctree.rst

   andes.io

Interoperability
================

.. autosummary::
   :maxdepth:4
   :toctree: _generated
   :recursive:
   :caption: Interoperability
   :template: autosummary/module_toctree.rst

   andes.interop


Others
======

.. autosummary::
   :maxdepth:4
   :toctree: _generated
   :recursive:
   :caption: Others
   :template: autosummary/module_toctree.rst

   andes.cli
   andes.main
   andes.utils.paths
   andes.utils.snapshot
   andes.utils.widgets